==> jc-1.4.0.tar.gz: java/util/regex/PatternSyntaxException.h <==
// public class java.util.regex.PatternSyntaxException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e4df2e08b92e1473 java_util_regex_PatternSyntaxException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_util_regex_PatternSyntaxException_H_
#define _JC_java_util_regex_PatternSyntaxException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_regex_PatternSyntaxException$sub_refs	_jc_java_util_regex_PatternSyntaxException$sub_refs;
typedef struct _jc_java_util_regex_PatternSyntaxException$sub_nonrefs	_jc_java_util_regex_PatternSyntaxException$sub_nonrefs;
typedef struct _jc_java_util_regex_PatternSyntaxException$refs	_jc_java_util_regex_PatternSyntaxException$refs;
typedef struct _jc_java_util_regex_PatternSyntaxException$nonrefs	_jc_java_util_regex_PatternSyntaxException$nonrefs;
typedef struct _jc_java_util_regex_PatternSyntaxException$object	_jc_java_util_regex_PatternSyntaxException$object;

typedef struct _jc_java_util_regex_PatternSyntaxException$fields_struct	_jc_java_util_regex_PatternSyntaxException$fields_struct;
typedef const struct _jc_java_util_regex_PatternSyntaxException$vmethods	_jc_java_util_regex_PatternSyntaxException$vmethods;
typedef const struct _jc_java_util_regex_PatternSyntaxException$vtable	_jc_java_util_regex_PatternSyntaxException$vtable;
typedef const struct _jc_java_util_regex_PatternSyntaxException$vtype	_jc_java_util_regex_PatternSyntaxException$vtype;

// Class fields structure
struct _jc_java_util_regex_PatternSyntaxException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_regex_PatternSyntaxException$fields_struct _jc_java_util_regex_PatternSyntaxException$class_fields;

// Constructors
extern void _jc_java_util_regex_PatternSyntaxException$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_regex_PatternSyntaxException$method$getDescription$2661fc1f3e986b4b(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
extern jint _jc_java_util_regex_PatternSyntaxException$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_regex_PatternSyntaxException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
extern struct _jc_java_lang_String$object *_jc_java_util_regex_PatternSyntaxException$method$getPattern$0b82bcfbcbeb75f3(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getDescription$2661fc1f3e986b4b;
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getPattern$0b82bcfbcbeb75f3;

// Virtual methods structure
struct _jc_java_util_regex_PatternSyntaxException$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$2661fc1f3e986b4b)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
	struct _jc_java_lang_String$object	*(*getPattern$0b82bcfbcbeb75f3)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *);
};

// Vtable
struct _jc_java_util_regex_PatternSyntaxException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_util_regex_PatternSyntaxException$vmethods	java_util_regex_PatternSyntaxException;
};

// Vtype
struct _jc_java_util_regex_PatternSyntaxException$vtype {
	_jc_type			type;
	_jc_java_util_regex_PatternSyntaxException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_regex_PatternSyntaxException$sub_refs {
	struct _jc_java_lang_String$object	*desc;
	struct _jc_java_lang_String$object	*pattern;
};

// Reference instance fields (object)
struct _jc_java_util_regex_PatternSyntaxException$refs {
    _jc_java_util_regex_PatternSyntaxException$sub_refs	java_util_regex_PatternSyntaxException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_regex_PatternSyntaxException$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_util_regex_PatternSyntaxException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_util_regex_PatternSyntaxException$sub_nonrefs	java_util_regex_PatternSyntaxException;
};

// Object instance structure
struct _jc_java_util_regex_PatternSyntaxException$object {
	_jc_java_util_regex_PatternSyntaxException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_regex_PatternSyntaxException$vtype	*vtype;
	_jc_java_util_regex_PatternSyntaxException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_regex_PatternSyntaxException$vtype _jc_java_util_regex_PatternSyntaxException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_regex_PatternSyntaxException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_regex_PatternSyntaxException$class_object;

#endif	/* _JC_java_util_regex_PatternSyntaxException_H_ */

==> jc-1.4.6.tar.gz: java/util/regex/PatternSyntaxException.h <==
// public class java.util.regex.PatternSyntaxException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class e4df2e08b92e1473 java_util_regex_PatternSyntaxException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_util_regex_PatternSyntaxException_H_
#define _JC_java_util_regex_PatternSyntaxException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_util_regex_PatternSyntaxException$sub_refs	_jc_java_util_regex_PatternSyntaxException$sub_refs;
typedef struct _jc_java_util_regex_PatternSyntaxException$sub_nonrefs	_jc_java_util_regex_PatternSyntaxException$sub_nonrefs;
typedef struct _jc_java_util_regex_PatternSyntaxException$refs	_jc_java_util_regex_PatternSyntaxException$refs;
typedef struct _jc_java_util_regex_PatternSyntaxException$nonrefs	_jc_java_util_regex_PatternSyntaxException$nonrefs;
typedef struct _jc_java_util_regex_PatternSyntaxException$object	_jc_java_util_regex_PatternSyntaxException$object;

typedef struct _jc_java_util_regex_PatternSyntaxException$fields_struct	_jc_java_util_regex_PatternSyntaxException$fields_struct;
typedef const struct _jc_java_util_regex_PatternSyntaxException$vmethods	_jc_java_util_regex_PatternSyntaxException$vmethods;
typedef const struct _jc_java_util_regex_PatternSyntaxException$vtable	_jc_java_util_regex_PatternSyntaxException$vtable;
typedef const struct _jc_java_util_regex_PatternSyntaxException$vtype	_jc_java_util_regex_PatternSyntaxException$vtype;

// Class fields structure
struct _jc_java_util_regex_PatternSyntaxException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_regex_PatternSyntaxException$fields_struct _jc_java_util_regex_PatternSyntaxException$class_fields;

// Constructors
extern void _jc_java_util_regex_PatternSyntaxException$method$_init$3814f9e0ae93d685(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_regex_PatternSyntaxException$method$getDescription$2661fc1f3e986b4b(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_regex_PatternSyntaxException$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_regex_PatternSyntaxException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_util_regex_PatternSyntaxException$method$getPattern$0b82bcfbcbeb75f3(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getDescription$2661fc1f3e986b4b;
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_java_util_regex_PatternSyntaxException$method_info$getPattern$0b82bcfbcbeb75f3;

// Virtual methods structure
struct _jc_java_util_regex_PatternSyntaxException$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$2661fc1f3e986b4b)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getPattern$0b82bcfbcbeb75f3)(_jc_env *, struct _jc_java_util_regex_PatternSyntaxException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_regex_PatternSyntaxException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_util_regex_PatternSyntaxException$vmethods	java_util_regex_PatternSyntaxException;
};

// Vtype
struct _jc_java_util_regex_PatternSyntaxException$vtype {
	_jc_type			type;
	_jc_java_util_regex_PatternSyntaxException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_regex_PatternSyntaxException$sub_refs {
	struct _jc_java_lang_String$object	*desc;
	struct _jc_java_lang_String$object	*pattern;
};

// Reference instance fields (object)
struct _jc_java_util_regex_PatternSyntaxException$refs {
    _jc_java_util_regex_PatternSyntaxException$sub_refs	java_util_regex_PatternSyntaxException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_regex_PatternSyntaxException$sub_nonrefs {
	jint	index;
};

// Non-reference instance fields (object)
struct _jc_java_util_regex_PatternSyntaxException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_util_regex_PatternSyntaxException$sub_nonrefs	java_util_regex_PatternSyntaxException;
};

// Object instance structure
struct _jc_java_util_regex_PatternSyntaxException$object {
	_jc_java_util_regex_PatternSyntaxException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_regex_PatternSyntaxException$vtype	*vtype;
	_jc_java_util_regex_PatternSyntaxException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_regex_PatternSyntaxException$vtype _jc_java_util_regex_PatternSyntaxException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_regex_PatternSyntaxException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_regex_PatternSyntaxException$class_object;

#endif	/* _JC_java_util_regex_PatternSyntaxException_H_ */
